import { Api } from './api';
import { PathEvent, PathEventEmitter } from '@ztimson/utils';
import { Meta } from './core';
import { User } from './users';
export type AuthOptions = {
    /** Path to login page */
    loginUrl?: string;
};
export type UserToken = Meta & {
    name: string;
    owner: string;
    token: string;
    expire: null | Date;
};
export declare class Token extends PathEventEmitter {
    private api;
    constructor(api: Api);
    all(username: string): Promise<UserToken[]>;
    create(token: {
        name: string;
        owner: string;
        expire: null | Date;
    }): Promise<UserToken>;
    delete(id: string): Promise<void>;
}
export declare class Totp {
    private api;
    constructor(api: Api);
    disable(username: string): import('@ztimson/utils').PromiseProgress<void>;
    enable: (username: string) => import('@ztimson/utils').PromiseProgress<void>;
    reset(username: string): import('@ztimson/utils').PromiseProgress<void>;
    setup(username: string, method?: string, totp?: string): import('@ztimson/utils').PromiseProgress<void>;
}
export declare class Auth extends PathEventEmitter {
    private readonly opts;
    private readonly api;
    token: Token;
    totp: Totp;
    private _permissions;
    get permissions(): string[];
    set permissions(perms: string[]);
    private _user?;
    get user(): User | null | undefined;
    set user(user: User | null | undefined);
    constructor(api: Api | string, opts?: AuthOptions);
    filter: (...events: (string | PathEvent)[]) => PathEvent[];
    has: (...events: (string | PathEvent)[]) => boolean;
    hasAll: (...events: (string | PathEvent)[]) => boolean;
    hasFatal: (...events: (string | PathEvent)[]) => void;
    hasAllFatal: (...events: (string | PathEvent)[]) => void;
    knownHost(host?: string): Promise<void>;
    login(username: string, password: string, opts?: {
        totp?: string;
        expire?: number | Date | null;
    }): Promise<User | null>;
    loginRedirect(host?: string): Promise<string>;
    logout(): void;
    register(u: Partial<User> & {
        username: string;
        password: string;
    }): Promise<User>;
    reset(password: string, token?: string): Promise<void>;
    reset(email: string): Promise<void>;
    session(token?: string, set?: boolean): Promise<{
        token: string;
        user: User;
        permissions: string[];
    } | null>;
    updatePassword(username: string, password: string, oldPassword?: string): Promise<void>;
}
//# sourceMappingURL=auth.d.ts.map